##  Setting Up Out-of-the-Box Integrations
The Integrations section of the administration area is the central location for configuring and managing all available integrations. This section lists all configured integrations along with their statuses, which help identify erroneous integrations. By selecting an integration, you can access its settings and make any necessary changes to the configuration.
To add and set up a new integration, click Add integrations at the top of the page. The next page lists all available integrations. Click Configure on the desired integration to set it up.
![Accessing Out-of-the-Box Integrations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749c2d47a4410148d42f768d3cb76f2_LowRes.png)
Setting-up Out-of-the-Box Integrations
